@@ -1,44 +1,37 @@
-package Log::Any::Adapter::MacOS::OSLog v0.0.4;
+package Log::Any::Adapter::MacOS::OSLog v0.0.5;
 
-## no critic (Documentation::RequirePodAtEnd)
+# ABSTRACT: log to macOS' unified logging system
 
-=for stopwords macOS FFI
-
-=head1 NAME
-
-Log::Any::Adapter::MacOS::OSLog - log to macOS' unified logging system
-
-=head1 VERSION
-
-version 0.0.4
-
-=head1 SYNOPSIS
-
-    use Log::Any::Adapter ('MacOS::OSLog',
-      subsystem => 'com.example.foo',
-    );
-
-    # or
-
-    use Log::Any::Adapter;
-    Log::Any::Adapter->set('MacOS::OSLog',
-      subsystem => 'org.example.bar',
-    );
-
-    # You can override defaults:
-    Log::Any::Adapter->set('MacOS::OSLog',
-      subsystem   => 'net.example.baz',
-      os_category => 'secret',
-      private     => 1,
-    );
-
-=head1 DESCRIPTION
-
-This L<Log::Any> adapter lets Perl applications log directly to macOS'
-L<unified logging system|https://developer.apple.com/documentation/os/logging>
-using FFI and C wrappers--no Swift required.
-
-=cut
+#pod =head1 SYNOPSIS
+#pod
+#pod     use Log::Any::Adapter ('MacOS::OSLog',
+#pod       subsystem => 'com.example.foo',
+#pod     );
+#pod
+#pod     # or
+#pod
+#pod     use Log::Any::Adapter;
+#pod     Log::Any::Adapter->set('MacOS::OSLog',
+#pod       subsystem => 'org.example.bar',
+#pod     );
+#pod
+#pod     # You can override defaults:
+#pod     Log::Any::Adapter->set('MacOS::OSLog',
+#pod       subsystem   => 'net.example.baz',
+#pod       os_category => 'secret',
+#pod       private     => 1,
+#pod     );
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This L<Log::Any> adapter lets Perl applications log directly to macOS'
+#pod L<unified logging system|https://developer.apple.com/documentation/os/logging>
+#pod using FFI and C wrappers--no Swift required.
+#pod
+#pod To send log entries easily from the command line, a C<maclog> utility
+#pod script is also included in this distribution.
+#pod
+#pod =cut
 
 use 5.018;
 use warnings;
@@ -63,34 +56,30 @@ for ( keys %LOG_LEVEL_ALIASES ) {
     $LOGGING_LEVELS{$_} = $LOGGING_LEVELS{ $LOG_LEVEL_ALIASES{$_} };
 }
 
-=head1 SUBROUTINES/METHODS
-
-=for stopwords init
-
-=head2 init
-
-This method is not called directly, but rather is passed named arguments
-as a hash when setting a L<Log::Any::Adapter>:
-
-=over
-
-=item subsystem
-
-=for stopwords DNS FQDN
-
-Required. Must be a reversed fully-qualified domain name (FQDN), e.g.,
-C<com.example.perl>.
-
-=item log_level, min_level, level
-
-These are all synonymous and strings that set the minimum logging level
-for the adapter. Whatever level is set, messages for that level and
-above will be logged.
-
-Defaults to C<trace> and is affected by various
-L<environment variables|/"CONFIGURATION AND ENVIRONMENT">.
-
-=cut
+#pod =method init
+#pod
+#pod This method is not called directly, but rather is passed named arguments
+#pod as a hash when setting a L<Log::Any::Adapter>:
+#pod
+#pod =over
+#pod
+#pod =item subsystem
+#pod
+#pod =for stopwords FQDN
+#pod
+#pod Required. Must be a reversed fully-qualified domain name (FQDN), e.g.,
+#pod C<com.example.perl>.
+#pod
+#pod =item log_level, min_level, level
+#pod
+#pod These are all synonymous and strings that set the minimum logging level
+#pod for the adapter. Whatever level is set, messages for that level and
+#pod above will be logged.
+#pod
+#pod Defaults to C<trace> and is affected by various
+#pod L<environment variables|/"CONFIGURATION AND ENVIRONMENT">.
+#pod
+#pod =cut
 
 sub _min_level {
     my $self = shift;
@@ -104,21 +93,21 @@ sub _min_level {
     return 'trace';
 }
 
-=item os_category
-
-Not to be confused with L<Log::Any categories|Log::Any/CATEGORIES>,
-this is used to categorize log entries in the unified log. However, just
-to keep things simple, it defaults to the name of the category used by
-L<Log::Any>.
-
-=item private
-
-Optional, defaults to false. A Boolean value indicating whether logged
-messages should be redacted in the macOS unified logging system.
-
-=back
-
-=cut
+#pod =item os_category
+#pod
+#pod Not to be confused with L<Log::Any categories|Log::Any/CATEGORIES>,
+#pod this is used to categorize log entries in the unified log. However, just
+#pod to keep things simple, it defaults to the name of the category used by
+#pod L<Log::Any>.
+#pod
+#pod =item private
+#pod
+#pod Optional, defaults to false. A Boolean value indicating whether logged
+#pod messages should be redacted in the macOS unified logging system.
+#pod
+#pod =back
+#pod
+#pod =cut
 
 sub init {
     my $self = shift;
@@ -128,7 +117,7 @@ sub init {
         ||= $self->{min_level} || $self->{level} || $self->_min_level;
 
     # TODO: extract this into a Regexp::Common module
-    ## no critic (RegularExpressions::ProhibitComplexRegexes)
+    ## no critic (RegularExpressions::ProhibitComplexRegexes, RegularExpressions::RequireDotMatchAnything, RegularExpressions::RequireLineBoundaryMatching)
     croak 'subsystem must be reversed FQDN'
         if not defined $self->{subsystem}
         and $self->{subsystem} !~ m{^
@@ -155,39 +144,39 @@ sub init {
     return;
 }
 
-=head2 L<Log::Any> methods
-
-The following L<Log::Any> methods are mapped to macOS L<os_log(3)>
-functions as follows:
-
-=over
-
-=item * trace: L<os_log_debug(3)>
-
-=item * debug: L<os_log_debug(3)>
-
-=item * info (or inform): L<os_log_info(3)>
-
-=item * notice: L<os_log_info(3)>
-
-=item * warning: L<os_log_fault(3)>
-
-=item * error (or err): L<os_log_error(3)>
-
-=for stopwords crit
-
-=item * critical (or crit or fatal): L<os_log(3)>
-
-=item * alert: L<os_log(3)>
-
-=item * emergency: L<os_log(3)>
-
-=back
-
-Formatted methods like C<infof>, C<errorf>, etc., are supported via
-L<Log::Any>'s standard interface.
-
-=cut
+#pod =head2 L<Log::Any> methods
+#pod
+#pod The following L<Log::Any> methods are mapped to macOS L<os_log(3)>
+#pod functions as follows:
+#pod
+#pod =over
+#pod
+#pod =item * trace: L<os_log_debug(3)>
+#pod
+#pod =item * debug: L<os_log_debug(3)>
+#pod
+#pod =item * info (or inform): L<os_log_info(3)>
+#pod
+#pod =item * notice: L<os_log_info(3)>
+#pod
+#pod =item * warning: L<os_log_fault(3)>
+#pod
+#pod =item * error (or err): L<os_log_error(3)>
+#pod
+#pod =for stopwords crit
+#pod
+#pod =item * critical (or crit or fatal): L<os_log(3)>
+#pod
+#pod =item * alert: L<os_log(3)>
+#pod
+#pod =item * emergency: L<os_log(3)>
+#pod
+#pod =back
+#pod
+#pod Formatted methods like C<infof>, C<errorf>, etc., are supported via
+#pod L<Log::Any>'s standard interface.
+#pod
+#pod =cut
 
 my @OS_LOG_LEVEL_MAP = qw(
     os_log_debug
@@ -233,7 +222,7 @@ foreach my $method ( keys %LOGGING_LEVELS ) {
 }
 
 foreach my $method ( detection_methods() ) {
-    my $level = $method =~ s/^is_//r;
+    my $level = $method =~ s/^ is_ //rx;    ## no critic (RegularExpressions::RequireDotMatchAnything, RegularExpressions::RequireLineBoundaryMatching)
     make_method(
         $method,
         sub {
@@ -245,7 +234,7 @@ foreach my $method ( detection_methods() ) {
 }
 
 sub _find_my_bundle {
-    my @module_parts = split /::/, __PACKAGE__;
+    my @module_parts = split / :: /x, __PACKAGE__;    ## no critic (RegularExpressions::RequireDotMatchAnything, RegularExpressions::RequireLineBoundaryMatching)
 
     my $module_pm = $INC{ join( q{/}, @module_parts ) . '.pm' }
         or croak 'Cannot find module in @INC for ' . __PACKAGE__;    ## no critic (ValuesAndExpressions::RequireInterpolationOfMetachars)
@@ -259,6 +248,187 @@ sub _find_my_bundle {
     return -e $blib_path ? $blib_path : $bundle_path;
 }
 
+#pod =head1 DIAGNOSTICS
+#pod
+#pod Using this adapter without specifying a properly-formatted C<subsystem>
+#pod argument will throw an exception.
+#pod
+#pod =head1 CONFIGURATION AND ENVIRONMENT
+#pod
+#pod Configure the same as L<Log::Any>.
+#pod
+#pod The following environment variables can set the logging level if no
+#pod level is set on the adapter itself:
+#pod
+#pod =over
+#pod
+#pod =item * C<TRACE> sets the minimum level to B<trace>
+#pod
+#pod =item * C<DEBUG> sets the minimum level to B<debug>
+#pod
+#pod =item * C<VERBOSE> sets the minimum level to B<info>
+#pod
+#pod =item * C<QUIET> sets the minimum level to B<error>
+#pod
+#pod =back
+#pod
+#pod In addition, the C<LOG_LEVEL> environment variable may be set to a
+#pod string indicating the desired logging level.
+#pod
+#pod =head1 DEPENDENCIES
+#pod
+#pod =over
+#pod
+#pod =item * L<Log::Any::Adapter::Base>
+#pod
+#pod =cut
+
+use parent qw(Log::Any::Adapter::Base);
+
+#pod =item * L<Log::Any::Adapter::Util>
+#pod
+#pod =cut
+
+use Log::Any::Adapter::Util qw(
+    detection_methods
+    log_level_aliases
+    logging_methods
+    make_method
+    numeric_level
+);
+
+#pod =item * L<FFI::Platypus> 2.00 or greater
+#pod
+#pod =cut
+
+use FFI::Platypus 2.00;
+
+#pod =item * L<namespace::autoclean>
+#pod
+#pod =cut
+
+use namespace::autoclean;
+
+#pod =back
+#pod
+#pod =cut
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Log::Any::Adapter::MacOS::OSLog - log to macOS' unified logging system
+
+=head1 VERSION
+
+version 0.0.5
+
+=head1 SYNOPSIS
+
+    use Log::Any::Adapter ('MacOS::OSLog',
+      subsystem => 'com.example.foo',
+    );
+
+    # or
+
+    use Log::Any::Adapter;
+    Log::Any::Adapter->set('MacOS::OSLog',
+      subsystem => 'org.example.bar',
+    );
+
+    # You can override defaults:
+    Log::Any::Adapter->set('MacOS::OSLog',
+      subsystem   => 'net.example.baz',
+      os_category => 'secret',
+      private     => 1,
+    );
+
+=head1 DESCRIPTION
+
+This L<Log::Any> adapter lets Perl applications log directly to macOS'
+L<unified logging system|https://developer.apple.com/documentation/os/logging>
+using FFI and C wrappers--no Swift required.
+
+To send log entries easily from the command line, a C<maclog> utility
+script is also included in this distribution.
+
+=head1 METHODS
+
+=head2 init
+
+This method is not called directly, but rather is passed named arguments
+as a hash when setting a L<Log::Any::Adapter>:
+
+=over
+
+=item subsystem
+
+=for stopwords FQDN
+
+Required. Must be a reversed fully-qualified domain name (FQDN), e.g.,
+C<com.example.perl>.
+
+=item log_level, min_level, level
+
+These are all synonymous and strings that set the minimum logging level
+for the adapter. Whatever level is set, messages for that level and
+above will be logged.
+
+Defaults to C<trace> and is affected by various
+L<environment variables|/"CONFIGURATION AND ENVIRONMENT">.
+
+=item os_category
+
+Not to be confused with L<Log::Any categories|Log::Any/CATEGORIES>,
+this is used to categorize log entries in the unified log. However, just
+to keep things simple, it defaults to the name of the category used by
+L<Log::Any>.
+
+=item private
+
+Optional, defaults to false. A Boolean value indicating whether logged
+messages should be redacted in the macOS unified logging system.
+
+=back
+
+=head2 L<Log::Any> methods
+
+The following L<Log::Any> methods are mapped to macOS L<os_log(3)>
+functions as follows:
+
+=over
+
+=item * trace: L<os_log_debug(3)>
+
+=item * debug: L<os_log_debug(3)>
+
+=item * info (or inform): L<os_log_info(3)>
+
+=item * notice: L<os_log_info(3)>
+
+=item * warning: L<os_log_fault(3)>
+
+=item * error (or err): L<os_log_error(3)>
+
+=for stopwords crit
+
+=item * critical (or crit or fatal): L<os_log(3)>
+
+=item * alert: L<os_log(3)>
+
+=item * emergency: L<os_log(3)>
+
+=back
+
+Formatted methods like C<infof>, C<errorf>, etc., are supported via
+L<Log::Any>'s standard interface.
+
 =head1 DIAGNOSTICS
 
 Using this adapter without specifying a properly-formatted C<subsystem>
@@ -292,42 +462,14 @@ string indicating the desired logging level.
 
 =item * L<Log::Any::Adapter::Base>
 
-=cut
-
-use base qw(Log::Any::Adapter::Base);
-
 =item * L<Log::Any::Adapter::Util>
 
-=cut
-
-use Log::Any::Adapter::Util qw(
-    detection_methods
-    log_level_aliases
-    logging_methods
-    make_method
-    numeric_level
-);
-
 =item * L<FFI::Platypus> 2.00 or greater
 
-=cut
-
-use FFI::Platypus 2.00;
-
 =item * L<namespace::autoclean>
 
-=cut
-
-use namespace::autoclean;
-
 =back
 
-=cut
-
-1;
-
-__END__
-
 =head1 INCOMPATIBILITIES
 
 Because this module relies on the macOS unified logging system
@@ -335,7 +477,7 @@ introduced in macOS Sierra version 10.12, it is incompatible with
 earlier versions of OS X, Mac OS X, the classic Mac OS, and all other
 non-Apple platforms (Microsoft Windows, Linux, other Unixes, etc.).
 
-=for stopwords iOS iPadOS tvOS watchOS
+=for stopwords iPadOS tvOS watchOS
 
 It could conceivably be built and run on Apple iOS, iPadOS, tvOS, and
 watchOS, but you'd have to build and deploy a native version of Perl
@@ -345,35 +487,14 @@ itself on those systems.
 
 Undoubtedly. Open an issue in the tracker.
 
-=head1 SUPPORT
-
-Source code and issue tracker:
-L<https://codeberg.org/mjgardner/perl-Log-Any-Adapter-MacOS-OSLog>
-
-=head2 Social media discussion
-
-=over
-
-=item * L<Mastodon|https://mastodon.phoenixtrap.com/@mjg/115008024722465194>
-
-=for stopwords Bluesky
-
-=item * L<Bluesky|https://bsky.app/profile/mjgardner.bsky.social/post/3lw3ueqbrwi2r>
-
-=item * L<Threads|https://www.threads.com/@mjgardner/post/DNMyRNrs-YO>
-
-=for stopwords LinkedIn
-
-=item * L<Facebook|https://www.facebook.com/share/p/1B73cxh5o8/>
-
-=item * L<LinkedIn|https://www.linkedin.com/posts/mjgardner_logging-from-perl-to-macos-unified-log-with-activity-7360513579751522304-wDgy>
-
-=back
-
 =head1 SEE ALSO
 
 =over
 
+=item * C<maclog>, a utility script included in this distribution,
+        used to send log entries easily from the command line or other
+        scripts
+
 =item * For a full write-up on the rationale, implementation, and
         integration details, see
         L<the blog post|https://phoenixtrap.com/2025/08/10/perl-macos-oslog>.
@@ -394,13 +515,96 @@ L<https://codeberg.org/mjgardner/perl-Log-Any-Adapter-MacOS-OSLog>
 
 =back
 
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Perldoc
+
+You can find documentation for this module with the perldoc command.
+
+  perldoc Log::Any::Adapter::MacOS::OSLog
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<https://metacpan.org/release/Log-Any-Adapter-MacOS-OSLog>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Log-Any-Adapter-MacOS-OSLog>
+
+=item *
+
+CPANTS
+
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
+
+L<http://cpants.cpanauthors.org/dist/Log-Any-Adapter-MacOS-OSLog>
+
+=item *
+
+CPAN Testers
+
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/L/Log-Any-Adapter-MacOS-OSLog>
+
+=item *
+
+CPAN Testers Matrix
+
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
+L<http://matrix.cpantesters.org/?dist=Log-Any-Adapter-MacOS-OSLog>
+
+=item *
+
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=Log::Any::Adapter::MacOS::OSLog>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests through the web interface at L<https://codeberg.org/mjgardner/perl-Log-Any-Adapter-MacOS-OSLog/issues>.
+
+=head2 Source Code
+
+The code is open to the world, and available for you to hack on. Please feel free to browse it and play
+with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
+from your repository :)
+
+L<https://codeberg.org/mjgardner/perl-Log-Any-Adapter-MacOS-OSLog>
+
+  git clone https://codeberg.org/mjgardner/perl-Log-Any-Adapter-MacOS-OSLog.git
+
 =head1 AUTHOR
 
 Mark Gardner <mjgardner@cpan.org>
 
-=head1 LICENSE AND COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2025 by Mark Gardner.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
+
+=cut
